"""
Scrapping script

@madeby Hercílio, Matheus e Pércio
"""
from datetime import date
import json
import sys
import env
import functions

"""
Script 1 - daily script
"""
def weeklyScript():
    print("Init Weekly Scraper")

    # File reader
    df = functions.handleFunctions(functions.readCSV, [env.CVM_FIS], 1, 'Arquivo CVM_FIS acessado com sucesso', 'Erro ao ler arquivo CVM_FIS')

    # remove cancelled
    df_1 = df.loc[df['SIT'] != 'CANCELADA']

    # get only the columns we want
    df_1 = df_1.filter(functions.getSelectedColumns(), axis=1)

    # merge duplicated rows
    df_1 = functions.handleFunctions(functions.mergeDuplicatedRows, [df_1], 2, 'Mesclou linhas com CNPJ duplicados', 'Erro ao mesclar linhas duplicadas')

    # Convert specif columns to string
    functions.convertSpecifColumnsToString(df_1)

    # remove all NaNs
    df_1.fillna('', inplace=True)

    # json with CNPJ as index
    df_json = functions.handleFunctions(functions.convertDataFrameToJsonByCNPJ, [df_1], 3, 'Converteu para JSON', 'Erro ao converte para JSON')

    # store data in rest api
    functions.handleFunctions(functions.storeData, [env.API_URL + "/fundo", env.API_KEY, df_json], 4, 'Dados salvos no backend', 'Erro ao fazer POST request ao backend')

"""
Script 2 - daily script
"""
def dailyScript():
    print("Init Daily Scraper")

    # get current date
    today = date.today()

    # set the current daily url
    url = f'{env.CVM_DAILY_FIS}/inf_diario_fi_{today.strftime("%Y%m")}.csv'

    # File Reader
    df = functions.handleFunctions(functions.readCSV, [url], 1, 'Arquivo CVM_DAILY_FIS acessado com sucesso', 'Erro ao ler arquivo CVM_DAILY_FIS')

    # Group by CNPJ_FUNDO and get the last occurrence of it
    df_2 = df.groupby(['CNPJ_FUNDO'], as_index=False, sort=False).tail(1)

    # remove all NaNs
    df_2 = df_2.fillna("")

    # json with CNPJ as index
    df_json = functions.handleFunctions(functions.convertDataFrameToJson, [df_2], 2, 'Converteu para JSON', 'Erro ao converte para JSON')

    # store data in rest api
    functions.handleFunctions(functions.storeData, [env.API_URL + "/update", env.API_KEY, df_json], 3, 'Dados salvos no backend', 'Erro ao fazer POST request ao backend')

def handler(event, context):
    # TODO: try catch
    # TODO: remove exit() from handleFunctions
    if 'type' in event:
        if event['type'] == 'weekly':
            weeklyScript()
        else:
            dailyScript()
        return {
            'statusCode': 200,
            'body': json.dumps('Successs!')
        }
    
    return {
        'statusCode': 400,
        'message': 'Missing body attribute "type"'
    }
