"""
Scrapping script

@madeby Hercílio, Matheus e Pércio
"""

import pandas as pd
import time
import requests
# Requests for AWS lambda
# from botocore.vendored import requests

# Variable to track the time
start_time = time.time()

## ================= ##
## Helper Functions: ##
## ================= ##
"""
Used to get the current time of the execution
"""
def getCurrentTime():
    global start_time
    return round((time.time() - start_time), 1)

"""
Handle thowable functions helper
"""
def handleFunctions(callback, params, id, success, error):
    try:
        result = callback(*params)
        print("{}. {} - {}".format(id, success, getCurrentTime()))
        return result
    except Exception as e:
        print("{}. {} - {}".format(id, error, getCurrentTime()))
        print("{}. Error: {}".format(id, str(e)))
        exit()



## ================= ##
## Pandas Functions: ##
## ================= ##

"""
Function to write a file
"""
def writeFile(filename, data, ext='csv', op='w'):
    f = open(filename + "." + ext, op)
    f.write(data)
    f.close()
    print("DONE")

"""
Return Selected Columns
"""
def getSelectedColumns():
    return ['CNPJ_FUNDO',
            'SIT',
            'ADMIN',
            'CD_CVM',
            'CLASSE',
            'CNPJ_ADMIN',
            'CONDOM',
            'CPF_CNPJ_GESTOR',
            'DENOM_SOCIAL',
            'DT_CANCEL',
            'DT_CONST',
            'DT_FIM_EXERC',
            'DT_INI_ATIV',
            'DT_INI_CLASSE',
            'DT_INI_EXERC',
            'DT_INI_SIT',
            'DT_PATRIM_LIQ',
            'FUNDO_COTAS',
            'FUNDO_EXCLUSIVO',
            'GESTOR',
            'INVEST_QUALIF',
            'PF_PJ_GESTOR',
            'RENTAB_FUNDO',
            'TAXA_ADM',
            'TAXA_PERFM',
            'TP_FUNDO',
            'TRIB_LPRAZO',
            'VL_PATRIM_LIQ',
            'AUDITOR',
            'CNPJ_AUDITOR']

"""
Callback function that merges non-unique duplicated values
"""
def aggregateDuplicatedRows(x):
    if x.size <= 1:
        return x
    if x.unique().size <= 1:
        return x.unique()
    return ', '.join(x.unique().astype(str))

"""
Convert specif columns to String
"""
def convertSpecifColumnsToString(df):
    columns = ['CD_CVM']
    for col in columns:
        df[col] = df[col].astype(str)


## =================== ##
## Scrapper Functions: ##
## =================== ##

"""
Read CSV files using pandas
"""
def readCSV(url):
    return pd.read_csv(url, sep=';', low_memory=False, encoding='latin1')

"""
Merge duplicated rows
"""
def mergeDuplicatedRows(df):
    return df.groupby(['CNPJ_FUNDO'], as_index=False, sort=False).aggregate(aggregateDuplicatedRows)

"""
Convert the pandas data frame to a JSON file with the
CNPJ_FUNDO as index
"""
def convertDataFrameToJsonByCNPJ(df):
    return df.set_index('CNPJ_FUNDO').to_dict('index')

"""
Convert the pandas data frame to a JSON file without custom index
"""
def convertDataFrameToJson(df):
    return list(df.to_dict('index').values())

"""
Store data into the REST API
"""
def storeData(url, key, json):
    r = requests.post(url, json=json, headers={'api-key': key})
    res = "%s - %s" % (r.status_code, r.reason)
    if (r.status_code != 200 and r.status_code != 201):
        raise Exception(res)
    return res
