"""
Scrapping script

@madeby Hercílio e Pércio
"""
import json
import sys
import env
import functions

"""
Script 1 - daily script

Params example:
    CSVs=['202105']
    day=['2021-05-01']
    day=["2021-05-03", "2021-05-04"]
"""
def getHistory(CSVs='202105', day=False, fundos=False):
    print("Init History Scraper")

    ## Step 1
    # File reader
    df = functions.handleFunctions(functions.readCSV, [env.CVM_FIS], 1, 'Arquivo CVM_FIS acessado com sucesso', 'Erro ao ler arquivo CVM_FIS')

    # remove cancelled
    df_1 = df.loc[df['SIT'] != 'CANCELADA']

    # Filter specific FEs
    if fundos:
        df_1 = df_1.loc[df_1['CNPJ_FUNDO'].isin(fundos)]

    # get only the CNPJ_FUNDO column
    df_1 = df_1['CNPJ_FUNDO']

    ## Step 2
    for csv in CSVs:
        # set the current daily url
        url = f'{env.CVM_DAILY_FIS}/inf_diario_fi_{csv}.csv'

        # File Reader
        df_2 = functions.handleFunctions(functions.readCSV, [url], 2, 'Arquivo CVM_DAILY_FIS acessado com sucesso', 'Erro ao ler arquivo CVM_DAILY_FIS')

        # remove all NaNs
        df_2 = df_2.fillna("")

        # Step 3
        df_3 = df_2.loc[df_2['CNPJ_FUNDO'].isin(df_1)]

        if day:
            df_3 = df_3.loc[df_3['DT_COMPTC'].isin(day)]
        
        if df_3.empty:
            print("DF empty")
            continue
        
        # Convert to JSON
        df_json = functions.handleFunctions(functions.convertDataFrameToJson, [df_3], 3, 'Converteu para JSON', 'Erro ao converte para JSON')

        # Store data in rest api
        functions.handleFunctions(functions.storeData, [env.API_URL + "/update", env.API_KEY, df_json], 4, 'Dados salvos no backend', 'Erro ao fazer POST request ao backend')

        print("History Scraper concluded", (csv, day), df_3.shape[0])


"""
24.986.670/0001-97: WARREN RF1 FUNDO DE INVESTIMENTO RENDA FIXA SIMPLES
29.577.652/0001-75: WARREN BRASIL FUNDO DE INVESTIMENTO EM AÇÕES
30.271.177/0001-93: WARREN FUNDO DE INVESTIMENTO EM COTAS DE FUNDOS DE INVESTIMENTO MULTIMERCADO CRÉDITO PRIVADO
29.577.706/0001-00: WARREN USA FUNDO DE INVESTIMENTO EM AÇÕES
"""
getHistory(CSVs=[
    '202001',
    '202002',
    '202003',
    '202004',
    '202005',
    '202006',
    '202007',
    '202008',
    '202009',
    '202010',
    '202011',
    '202012',
    '202101',
    '202102',
    '202103',
    '202104',
    '202105',
    ], fundos=[
    '24.986.670/0001-97',
    '29.577.652/0001-75',
    '30.271.177/0001-93',
    '29.577.706/0001-00',
])